"""
    BOAVIZTAPI - DEMO

    # 🎯 Retrieving the impacts of digital elements This is a quick demo, to see full documentation [click here](https://doc.api.boavizta.org)  ## ➡️Server router  ### Server routers support the following impacts:  | Impact | 🔨 Manufacture | 🔌 Usage | |--------|----------------|----------| |   GWP  |        X       |     X    | |   ADP  |        X       |     X    | |   PE   |        X       |     X    | ## ➡️Cloud router  ### Cloud routers support the following impacts:  | Impact | 🔨 Manufacture | 🔌 Usage | |--------|----------------|----------| |   GWP  |        X       |     X    | |   ADP  |        X       |     X    | |   PE   |        X       |     X    | ## ➡️Component router  ### Component routers support the following impacts:  | Impact | 🔨 Manufacture | 🔌 Usage | |--------|----------------|----------| |   GWP  |        X       |          | |   ADP  |        X       |          | |   PE   |        X       |          |   # noqa: E501

    The version of the OpenAPI document: 0.1.2
    Generated by: https://openapi-generator.tech
"""


import unittest

import boaviztapi-sdk
from boaviztapi-sdk.api.component_api import ComponentApi  # noqa: E501


class TestComponentApi(unittest.TestCase):
    """ComponentApi unit test stubs"""

    def setUp(self):
        self.api = ComponentApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_case_impact_bottom_up_v1_component_case_post(self):
        """Test case for case_impact_bottom_up_v1_component_case_post

        Case Impact Bottom Up  # noqa: E501
        """
        pass

    def test_cpu_impact_bottom_up_v1_component_cpu_post(self):
        """Test case for cpu_impact_bottom_up_v1_component_cpu_post

        Cpu Impact Bottom Up  # noqa: E501
        """
        pass

    def test_disk_impact_bottom_up_v1_component_hdd_post(self):
        """Test case for disk_impact_bottom_up_v1_component_hdd_post

        Disk Impact Bottom Up  # noqa: E501
        """
        pass

    def test_disk_impact_bottom_up_v1_component_ssd_post(self):
        """Test case for disk_impact_bottom_up_v1_component_ssd_post

        Disk Impact Bottom Up  # noqa: E501
        """
        pass

    def test_motherboard_impact_bottom_up_v1_component_motherboard_post(self):
        """Test case for motherboard_impact_bottom_up_v1_component_motherboard_post

        Motherboard Impact Bottom Up  # noqa: E501
        """
        pass

    def test_power_supply_impact_bottom_up_v1_component_power_supply_post(self):
        """Test case for power_supply_impact_bottom_up_v1_component_power_supply_post

        Power Supply Impact Bottom Up  # noqa: E501
        """
        pass

    def test_ram_impact_bottom_up_v1_component_ram_post(self):
        """Test case for ram_impact_bottom_up_v1_component_ram_post

        Ram Impact Bottom Up  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
