# flake8: noqa

"""
    BOAVIZTAPI - DEMO

    # 🎯 Retrieving the impacts of digital elements This is a quick demo, to see full documentation [click here](https://doc.api.boavizta.org)  ## ➡️Server router  ### Server routers support the following impacts:  | Impact | 🔨 Manufacture | 🔌 Usage | |--------|----------------|----------| |   GWP  |        X       |     X    | |   ADP  |        X       |     X    | |   PE   |        X       |     X    | ## ➡️Cloud router  ### Cloud routers support the following impacts:  | Impact | 🔨 Manufacture | 🔌 Usage | |--------|----------------|----------| |   GWP  |        X       |     X    | |   ADP  |        X       |     X    | |   PE   |        X       |     X    | ## ➡️Component router  ### Component routers support the following impacts:  | Impact | 🔨 Manufacture | 🔌 Usage | |--------|----------------|----------| |   GWP  |        X       |          | |   ADP  |        X       |          | |   PE   |        X       |          |   # noqa: E501

    The version of the OpenAPI document: 0.1.2
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from boaviztapi-sdk.api_client import ApiClient

# import Configuration
from boaviztapi-sdk.configuration import Configuration

# import exceptions
from boaviztapi-sdk.exceptions import OpenApiException
from boaviztapi-sdk.exceptions import ApiAttributeError
from boaviztapi-sdk.exceptions import ApiTypeError
from boaviztapi-sdk.exceptions import ApiValueError
from boaviztapi-sdk.exceptions import ApiKeyError
from boaviztapi-sdk.exceptions import ApiException
